SunPy Documentation
*******************

Welcome to SunPy's documentation.

SunPy is a community-developed, free and open-source solar data analysis environment for Python.

Here, we detail each part of SunPy and provide a user guide and a gallery of examples.

Documentation :any:`index <genindex>` and :any:`Module <modindex>` index.

.. toctree::
  :maxdepth: 2

  guide/index
  code_ref/index
  generated/gallery/index
  dev_guide/index
  whatsnew/index
  code_of_conduct
  about
